ColumnRelationAction

Enum ColumnRelationAction 

pub enum ColumnRelationAction {
    Restrict,
    Cascade,
    SetNull,
    SetDefault,
    NoAction,
}
The action that should be performed when a referenced row is deleted or updated.

Variants



Restrict

The default action. The database will not allow the deletion or update of the referenced row.



Cascade

The database will delete or update the row from the table if that row is deleted or updated from the parent table.



SetNull

The database will set the foreign key column or columns in the referencing row to NULL if that row is deleted or updated from the parent table.



SetDefault

The database will set the foreign key column or columns in the referencing row to the default value if that row is deleted or updated from the parent table.



NoAction

Just ignore and do nothing